Changelog
=========

2.1.1
-----
 - corrected doctests

2.1.0
-----
 - added support for overlay vs base layers
 - added support for hidden layers
 - updated coordinates transformation API
 - updated Gitlab CI configuration

2.0.2
-----
 - corrected doctest and Gitlab-CI configuration

2.0.1
-----
 - updated Gitlab-CI configuration

2.0.0
-----
 - initial release
